@@ -11,6 +11,7 @@ import os
 import sys
 import threading
 import time
+from urllib.request import build_opener
 
 from gi.repository import Gtk, GLib, Pango, Gdk
 import feedparser
@@ -25,7 +26,6 @@ from quodlibet import util
 from quodlibet import app
 
 from quodlibet.browsers import Browser
-from quodlibet.compat import listfilter, text_type, build_opener, PY2
 from quodlibet.formats import AudioFile
 from quodlibet.formats.remote import RemoteFile
 from quodlibet.qltk.getstring import GetStringDialog
@@ -173,7 +173,7 @@ class Feed(list):
                                 "ogg" in enclosure.type or
                                 formats.filter(enclosure.url)):
                             uri = enclosure.url
-                            if not isinstance(uri, text_type):
+                            if not isinstance(uri, str):
                                 uri = uri.decode('utf-8')
                             try:
                                 size = float(enclosure.length)
@@ -225,7 +225,7 @@ class Feed(list):
             ct_hdr = result.headers.get('Content-Type', "Unknown type")
             content_type = ct_hdr.split(';')[0]
             try:
-                status = result.code if PY2 else result.status
+                status = result.status
             except AttributeError:
                 print_w("Missing status code for feed %s" % self.uri)
             else:
@@ -252,7 +252,7 @@ class AddFeedDialog(GetStringDialog):
     def run(self, text='', test=False):
         uri = super(AddFeedDialog, self).run(text=text, test=test)
         if uri:
-            if not isinstance(uri, text_type):
+            if not isinstance(uri, str):
                 uri = uri.decode('utf-8')
             return Feed(uri)
         return None
@@ -494,7 +494,7 @@ class AudioFeeds(Browser):
         AudioFeeds.write()
 
     def __refresh(self, feeds):
-        changed = listfilter(Feed.parse, feeds)
+        changed = list(filter(Feed.parse, feeds))
         AudioFeeds.changed(changed)
 
     def __remove_paths(self, model, paths):
