@@ -13,7 +13,6 @@ from senf import bytes2fsn, fsn2bytes
 
 from quodlibet import const
 from quodlibet.util import print_d, print_w
-from quodlibet.compat import text_type, iteritems
 from .tcpserver import BaseTCPServer, BaseTCPConnection
 
 
@@ -202,7 +201,7 @@ class MPDService(object):
 
     def flush_idle(self):
         flushed = []
-        for conn, subs in iteritems(self._idle_subscriptions):
+        for conn, subs in self._idle_subscriptions.items():
             # figure out which subsystems to report for each connection
             queued = self._idle_queue[conn]
             if subs:
@@ -227,7 +226,7 @@ class MPDService(object):
         self._idle_subscriptions.pop(connection, None)
 
     def emit_changed(self, subsystem):
-        for conn, subs in iteritems(self._idle_queue):
+        for conn, subs in self._idle_queue.items():
             subs.add(subsystem)
         self.flush_idle()
 
@@ -322,6 +321,10 @@ class MPDService(object):
         ]
 
         if info:
+            status.append(("audio", "%d:%d:%d" % (
+                info("~#samplerate") or 0,
+                info("~#bitdepth") or 0,
+                info("~#channels") or 0)))
             total_time = int(info("~#length"))
             elapsed_time = int(app.player.get_position() / 1000)
             elapsed_exact = "%1.3f" % (app.player.get_position() / 1000.0)
@@ -413,7 +416,7 @@ class MPDConnection(BaseTCPConnection):
         self.service = service
         service.add_connection(self)
 
-        str_version = u".".join(map(text_type, service.version))
+        str_version = u".".join(map(str, service.version))
         self._buf = bytearray((u"OK MPD %s\n" % str_version).encode("utf-8"))
         self._read_buf = bytearray()
 
@@ -499,7 +502,7 @@ class MPDConnection(BaseTCPConnection):
     def write_line(self, line):
         """Writes a line to the client"""
 
-        assert isinstance(line, text_type)
+        assert isinstance(line, str)
         self.log(u"<- " + repr(line))
 
         self._buf.extend(line.encode("utf-8", errors="replace") + b"\n")
@@ -829,7 +832,7 @@ def _cmd_outputs(conn, service, args):
 @MPDConnection.Command("commands", permission=Permissions.PERMISSION_NONE)
 def _cmd_commands(conn, service, args):
     for name in conn.list_commands():
-        conn.write_line(u"command: " + text_type(name))
+        conn.write_line(u"command: " + str(name))
 
 
 @MPDConnection.Command("tagtypes")
