@@ -2,8 +2,9 @@
 # Copyright 2004-2005 Joe Wreschnig, Michael Urman, Iñigo Serna
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk, Gdk, GObject
 
@@ -13,12 +14,18 @@ from quodlibet import _
 from quodlibet.util import connect_obj, connect_destroy
 from quodlibet.qltk.x import SymbolicIconImage, RadioMenuItem
 from quodlibet.qltk.seekbutton import SeekButton
+from quodlibet.util.dprint import print_e
 
 
 class Volume(Gtk.VolumeButton):
     def __init__(self, player):
         super(Volume, self).__init__(size=Gtk.IconSize.MENU, use_symbolic=True)
 
+        # https://bugzilla.gnome.org/show_bug.cgi?id=781605
+        scales = qltk.find_widgets(self.get_popup(), Gtk.Scale)
+        if scales:
+            scales[0].props.round_digits = -1
+
         self.set_relief(Gtk.ReliefStyle.NORMAL)
         self.set_adjustment(Gtk.Adjustment.new(0, 0, 1, 0.05, 0.1, 0))
 
@@ -123,6 +130,10 @@ class VolumeMenu(Gtk.Menu):
         self.append(item)
         item.show()
 
+        # Set replaygain mode as saved in configuration
+        replaygain_mode = config.gettext("player", "replaygain_mode", "auto")
+        self.__set_mode(player, replaygain_mode)
+
         rg = Gtk.Menu()
         rg.show()
         item.set_submenu(rg)
@@ -131,15 +142,25 @@ class VolumeMenu(Gtk.Menu):
             item = RadioMenuItem(group=item, label=title,
                                  use_underline=True)
             rg.append(item)
-            item.connect("toggled", self.__changed, player, profile)
-            if player.replaygain_profiles[0] == profile:
+            item.connect("toggled", self.__changed, player, mode)
+            if replaygain_mode == mode:
                 item.set_active(True)
             item.show()
 
-    def __changed(self, item, player, profile):
+    def __set_mode(self, player, mode):
+        selected_mode = next((m for m in self.__modes if m[0] == mode), None)
+        if selected_mode is None:
+            print_e("Invalid selected replaygain mode: %r" % mode)
+            selected_mode = self.__modes[0]
+            print_e("Falling back to replaygain mode: %r" % selected_mode[0])
+
+        player.replaygain_profiles[0] = selected_mode[2]
+        player.reset_replaygain()
+
+    def __changed(self, item, player, mode):
         if item.get_active():
-            player.replaygain_profiles[0] = profile
-            player.reset_replaygain()
+            config.settext("player", "replaygain_mode", mode)
+            self.__set_mode(player, mode)
 
     def popup(self, *args):
         gain = config.getboolean("player", "replaygain")
@@ -264,11 +285,10 @@ class PlayControls(Gtk.VBox):
         play.set_active(not player.paused)
 
     def __playpause(self, button, player):
-        if button.get_active() and player.song is None:
-            player.reset()
-            button.set_active(not player.paused)
+        if button.get_active():
+            player.play()
         else:
-            player.paused = not button.get_active()
+            player.paused = True
 
     def __previous(self, player):
         player.previous()
