@@ -3,15 +3,18 @@
 #           2005 Joe Wreschnig
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 
 from gi.repository import Gtk
 
+from quodlibet import _
 from quodlibet import util
 from quodlibet import config
 from quodlibet import qltk
 from quodlibet.config import RATINGS
+from quodlibet.qltk import Icons
 from quodlibet.qltk import SeparatorMenuItem
 
 
@@ -32,24 +35,29 @@ class ConfirmRateMultipleDialog(qltk.Message):
         self.add_button(action_title, Gtk.ResponseType.YES)
 
 
-class RatingsMenuItem(Gtk.MenuItem):
+class RatingsMenuItem(Gtk.ImageMenuItem):
 
     def __init__(self, songs, library, label=_("_Rating")):
         super(RatingsMenuItem, self).__init__(label=label, use_underline=True)
         self._songs = songs
-        ratings = {song("~#rating") for song in songs if song.has_rating}
+        image = Gtk.Image.new_from_icon_name(Icons.FAVORITE, Gtk.IconSize.MENU)
+        image.show()
+        self.set_image(image)
 
         submenu = Gtk.Menu()
         self.set_submenu(submenu)
+        self._rating_menu_items = []
         for i in RATINGS.all:
             text = "%0.2f\t%s" % (i, util.format_rating(i))
             itm = Gtk.CheckMenuItem(label=text)
-            is_selected = i in ratings
-            itm.set_active(is_selected)
+            itm.rating = i
             submenu.append(itm)
-            itm.connect('activate', self._on_rating_change, i, library)
+            handler = itm.connect(
+                'toggled', self._on_rating_change, i, library)
+            self._rating_menu_items.append((itm, handler))
         reset = Gtk.MenuItem(label=_("_Remove Rating"), use_underline=True)
         reset.connect('activate', self._on_rating_remove, library)
+        self._select_ratings()
 
         submenu.append(SeparatorMenuItem())
         submenu.append(reset)
@@ -58,6 +66,23 @@ class RatingsMenuItem(Gtk.MenuItem):
     def set_songs(self, songs):
         """Set a new set of songs affected by the rating menu"""
         self._songs = songs
+        self._select_ratings()
+
+    def _select_ratings(self):
+        ratings = [song("~#rating") for song in self._songs
+                   if song and song.has_rating]
+        song_count = len(self._songs)
+        for (menu_item, handler) in self._rating_menu_items:
+            rating_val = menu_item.rating
+            rated_count = ratings.count(rating_val)
+            menu_item.handler_block(handler)
+            if rated_count == 0:
+                menu_item.set_active(False)
+            elif rated_count == song_count:
+                menu_item.set_active(True)
+            else:
+                menu_item.set_inconsistent(True)
+            menu_item.handler_unblock(handler)
 
     def _on_rating_change(self, menuitem, value, library):
         self.set_rating(value, self._songs, library)
