@@ -20,8 +20,6 @@ from senf import print_, path2fsn, fsn2text, fsnative, \
     supports_ansi_escape_codes
 
 from quodlibet import const
-from quodlibet.compat import PY2, text_type
-from .string import decode
 from . import logging as ql_logging
 
 
@@ -142,6 +140,8 @@ def frame_info(level=0):
     if not info:
         info = frame.f_globals.get("__name__", "")
 
+    info = str(info)
+
     # append the function/method name
     if info:
         info += "." + co_name
@@ -175,8 +175,8 @@ def _supports_ansi_escape_codes(file_):
 def _print_message(string, custom_context, debug_only, prefix,
                    color, logging_category, start_time=time.time()):
 
-    if not isinstance(string, (text_type, fsnative)):
-        string = text_type(string)
+    if not isinstance(string, (str, fsnative)):
+        string = str(string)
 
     context = frame_info(2)
 
@@ -221,21 +221,21 @@ def _print_message(string, custom_context, debug_only, prefix,
 
 
 def format_exception(etype, value, tb, limit=None):
-    """Returns a list of text_type"""
+    """Returns a list of str"""
 
     result_lines = traceback.format_exception(etype, value, tb, limit)
     return [fsn2text(path2fsn(l)) for l in result_lines]
 
 
 def format_exception_only(etype, value):
-    """Returns a list of text_type"""
+    """Returns a list of str"""
 
     result_lines = traceback.format_exception_only(etype, value)
     return [fsn2text(path2fsn(l)) for l in result_lines]
 
 
 def format_exc(limit=None):
-    """Returns text_type"""
+    """Returns str"""
 
     etype, value, tb = sys.exc_info()
     return u''.join(format_exception(etype, value, tb, limit))
@@ -244,20 +244,10 @@ def format_exc(limit=None):
 def extract_tb(*args, **kwargs):
     """Returns a list of tuples containing
 
-    (fsnative, int, text_type, text_type)
+    (fsnative, int, str, str)
     """
 
-    tp = traceback.extract_tb(*args, **kwargs)
-    if not PY2:
-        return tp
-
-    result = []
-    for filename, line_number, function_name, text in tp:
-        filename = path2fsn(filename)
-        function_name = decode(function_name)
-        text = decode(text or u"")
-        result.append((filename, line_number, function_name, text))
-    return result
+    return traceback.extract_tb(*args, **kwargs)
 
 
 def print_exc(exc_info=None, context=None):
